@@ -813,7 +813,7 @@ generate_spls_plots <- function(ns, input, output, dataSelection, classSelection
   output$Var.download <- getDownloadHandler("PLS_CorrelationCircleplot.png", plot.var)
   output$Load.download <- getDownloadHandler("PLS_Loadingsplot.png", plot.load, width = 2592, height = 1944)
   output$Load.table.download <- getDownloadHandler("PLS_Loadingsplot.xlsx", contentfct = loadingsToTable, 
-                                                         result = result, comp = input$load.comp, type = "wb")
+                                                         result = result, comp = reactive(input$load.comp), type = "wb")
   output$Img.download <- getDownloadHandler("PLS_Heatmap.png", plot.img, width = 2592, height = 1944)
   output$SelVarX.download <- getDownloadHandler("PLS_SelectedFeatures1.csv", table.selVarX, type = "csv")
   output$SelVarY.download <- getDownloadHandler("PLS_SelectedFeatures2.csv", table.selVarY, type = "csv")
@@ -825,7 +825,7 @@ generate_spls_plots <- function(ns, input, output, dataSelection, classSelection
   output$Var.download.tuned <- getDownloadHandler("PLS_tuned_CorrelationCircleplot.png", plot.var.tuned)
   output$Load.download.tuned <- getDownloadHandler("PLS_tuned_Loadingsplot.png", plot.load.tuned, width = 2592, height = 1944)
   output$Load.table.download.tuned <- getDownloadHandler("PLS_tuned_Loadingsplot.xlsx", contentfct = loadingsToTable, 
-                                                         result = resultTuned, comp = input$load.comp.tuned, type = "wb")
+                                                         result = resultTuned, comp = reactive(input$load.comp.tuned), type = "wb")
   output$Img.download.tuned <- getDownloadHandler("PLS_tuned_Heatmap.png", plot.img.tuned, width = 2592, height = 1944)
   output$SelVarX.download.tuned <- getDownloadHandler("PLS_tuned_SelectedFeatures1.csv", table.selVarX.tuned, type = "csv")
   output$SelVarY.download.tuned <- getDownloadHandler("PLS_tuned_SelectedFeatures2.csv", table.selVarY.tuned, type = "csv")
